@@ -1,8 +1,8 @@
-testthat::test_that("`identify_non_numeric_predictors()` works", {
+testthat::test_that("`identify_predictors_categorical()` works", {
 
     data(vi, vi_predictors)
 
-    non.numeric.predictors <- identify_non_numeric_predictors(
+    non.numeric.predictors <- identify_predictors_categorical(
       df = vi,
       predictors = vi_predictors
     )
@@ -18,10 +18,10 @@ testthat::test_that("`identify_non_numeric_predictors()` works", {
 
 })
 
-testthat::test_that("`identify_numeric_predictors()` works", {
+testthat::test_that("`identify_predictors_numeric()` works", {
 
     data(vi, vi_predictors)
-    numeric.predictors <- identify_numeric_predictors(
+    numeric.predictors <- identify_predictors_numeric(
       df = vi,
       predictors = vi_predictors
     )
@@ -37,14 +37,14 @@ testthat::test_that("`identify_numeric_predictors()` works", {
 
 })
 
-testthat::test_that("`identify_zero_variance_predictors()` works", {
+testthat::test_that("`identify_predictors_zero_variance()` works", {
 
     data(vi, vi_predictors)
     vi$zv_1 <- 1
     vi$zv_2 <- runif(n = nrow(vi), min = 0, max = 1e-04)
     vi_predictors <- c(vi_predictors, "zv_1", "zv_2")
 
-    zero.variance.predictors <- identify_zero_variance_predictors(
+    zero.variance.predictors <- identify_predictors_zero_variance(
       df = vi,
       predictors = vi_predictors
     )
@@ -59,3 +59,22 @@ testthat::test_that("`identify_zero_variance_predictors()` works", {
     )
 
 })
+
+
+testthat::test_that("`identify_predictors()` works", {
+
+  predictors <- identify_predictors(
+    df = vi,
+    predictors = vi_predictors
+  )
+
+  testthat::expect_true(
+    all(predictors$numeric %in% vi_predictors_numeric)
+  )
+
+  testthat::expect_true(
+    all(predictors$categorical %in% vi_predictors_categorical)
+  )
+
+})
+
